local lazypath = vim.fn.stdpath("data") .. "/lazy/lazy.nvim"
if not vim.loop.fs_stat(lazypath) then
  vim.fn.system({
    "git",
    "clone",
    "--filter=blob:none",
    "https://github.com/folke/lazy.nvim.git",
    "--branch=stable", -- latest stable release
    lazypath,
  })
end
vim.opt.rtp:prepend(lazypath)

plugins = {
  {
  'maxmx03/dracula.nvim',
  lazy = false,
  config = function ()
    local dracula = require 'dracula'
    dracula.setup()
    vim.cmd.colorscheme 'dracula'
  end
  },
  {
    "nvim-treesitter/nvim-treesitter",
    build = ":TSUpdate",
    config = function () 
      local configs = require("nvim-treesitter.configs")
      configs.setup({
	ensure_installed = { "c", "rust", "lua", "vim", "vimdoc", "javascript", "html", "astro" },
	sync_install = false,
	highlight = { enable = true },
	indent = { enable = true },  
      })
    end
  }
}

require("lazy").setup(plugins)

vim.opt.smarttab = true
vim.opt.expandtab = true
vim.opt.shiftwidth = 2
